@@ -381,7 +381,7 @@ void Kwave::PlaybackController::startDevicePlayBack()
 //***************************************************************************
 void Kwave::PlaybackController::stopDevicePlayBack()
 {
-    m_thread.cancel();
+    m_thread.requestInterruption();
     if (!m_thread.isRunning()) {
 	qDebug("PlaybackController::stopDevicePlayBack() - not running");
 	emit sigDevicePlaybackDone();
@@ -444,7 +444,7 @@ void Kwave::PlaybackController::run_wrapper(const QVariant &params)
 	// samples (this happens when resuming after a pause)
 	if (pos > first) input.skip(pos - first);
 
-	while ((pos++ <= last) && !m_thread.shouldStop()) {
+	while ((pos++ <= last) && !m_thread.isInterruptionRequested()) {
 	    unsigned int x;
 	    unsigned int y;
 	    bool seek_again = false;
@@ -507,12 +507,17 @@ void Kwave::PlaybackController::run_wrapper(const QVariant &params)
 	    // write samples to the playback device
 	    int result = -1;
 	    {
-		QMutexLocker lock(&m_lock_device);
-		if (m_device)
-		    result = m_device->write(out_samples);
+		unsigned int retry = 10;
+		while (retry-- && !m_thread.isInterruptionRequested()) {
+		    QMutexLocker lock(&m_lock_device);
+		    if (m_device)
+			result = m_device->write(out_samples);
+		    if (result == 0)
+			break;
+		}
 	    }
 	    if (result) {
-		m_thread.cancel();
+		m_thread.requestInterruption();
 		pos = last;
 	    }
 
@@ -528,12 +533,12 @@ void Kwave::PlaybackController::run_wrapper(const QVariant &params)
 
 	// maybe we loop. in this case the playback starts
 	// again from the left marker
-	if (m_loop_mode && !m_thread.shouldStop()) {
+	if (m_loop_mode && !m_thread.isInterruptionRequested()) {
 	    input.reset();
 	    pos = startPos();
 	}
 
-    } while (m_loop_mode && !m_thread.shouldStop());
+    } while (m_loop_mode && !m_thread.isInterruptionRequested());
 
     // playback is done
     emit sigDevicePlaybackDone();
